﻿using OpenGL;
using System;
using System.Collections.Generic;

namespace GameApp
{
    class Loader
    {
        List<uint> _vaos = new List<uint>();
        List<uint> _vbos = new List<uint>();

        public RawModel loadToVAO(float [] positions)
        {
            uint vaoID = createVAO();
            storeDataInAttributeList(0, positions);
            unbindVAO();

            return new RawModel(vaoID, positions.Length / 3);
        }

        public void CleanUp()
        {
            Gl.DeleteVertexArrays(_vaos.ToArray());
            Gl.DeleteBuffers(_vbos.ToArray());
        }

        uint createVAO()
        {
            uint vaoID = Gl.GenVertexArray();
            _vaos.Add(vaoID);
            Gl.BindVertexArray(vaoID);
            return vaoID;
        }

        unsafe void storeDataInAttributeList(uint attributeNumber, float [] data)
        {
            uint vboID = Gl.GenBuffer();

            _vbos.Add(vboID);

            Gl.BindBuffer(BufferTarget.ArrayBuffer, vboID);
            Gl.BufferData(BufferTarget.ArrayBuffer, (uint)(data.Length * sizeof(float)), data, BufferUsage.StaticDraw);

            Gl.VertexAttribPointer(attributeNumber, 3, VertexAttribType.Float, false, 0, IntPtr.Zero);
            Gl.BindBuffer(BufferTarget.ArrayBuffer, 0);
        }

        void unbindVAO()
        {
            Gl.BindVertexArray(0);
        }
    }
}
